@@ -1,4 +1,4 @@
-/* $Id: ClpLsqr.hpp 1370 2009-06-04 09:37:13Z forrest $ */
+/* $Id: ClpLsqr.hpp 1525 2010-02-26 17:27:59Z mjs $ */
 // Copyright (C) 2003, International Business Machines
 // Corporation and others.  All Rights Reserved.
 #ifndef ClpLsqr_H_
@@ -19,13 +19,13 @@ This class implements LSQR
  A  is an m by n matrix defined by user provided routines
  matVecMult(mode, y, x)
  which performs the matrix-vector operations where y and x
- are references or pointers to CoinDenseVector objects.  
+ are references or pointers to CoinDenseVector objects.
  If mode = 1, matVecMult  must return  y = Ax   without altering x.
  If mode = 2, matVecMult  must return  y = A'x  without altering x.
 
 -----------------------------------------------------------------------
  LSQR uses an iterative (conjugate-gradient-like) method.
- For further information, see 
+ For further information, see
  1. C. C. Paige and M. A. Saunders (1982a).
     LSQR: An algorithm for sparse linear equations and sparse least squares,
     ACM TOMS 8(1), 43-71.
@@ -66,66 +66,67 @@ This class implements LSQR
  var         estimates diag( inv(A'A) ).  Omitted in this special version.
  outfo       is a structure special to pdco.m, returning information
              about whether atol had to be reduced.
-             
+
  Other potential output parameters:
  anorm, acond, arnorm, xnorm
 @endverbatim
  */
-class ClpLsqr{
+class ClpLsqr {
 private:
-   /**@name Private member data */
-   //@{
-   //@}
+     /**@name Private member data */
+     //@{
+     //@}
 
 public:
-   /**@name Public member data */
-   //@{
-   /// Row dimension of matrix
-  int          nrows_;
-   /// Column dimension of matrix
-  int          ncols_;
-   /// Pointer to Model object for this instance
-  ClpInterior        *model_;
-   /// Diagonal array 1
-  double         *diag1_;
-   /// Constant diagonal 2
-  double         diag2_;
-   //@}  
+     /**@name Public member data */
+     //@{
+     /// Row dimension of matrix
+     int          nrows_;
+     /// Column dimension of matrix
+     int          ncols_;
+     /// Pointer to Model object for this instance
+     ClpInterior        *model_;
+     /// Diagonal array 1
+     double         *diag1_;
+     /// Constant diagonal 2
+     double         diag2_;
+     //@}
 
-   /**@name Constructors and destructors */
-  /** Default constructor */
-  ClpLsqr();
+     /**@name Constructors and destructors */
+     /** Default constructor */
+     ClpLsqr();
 
-  /** Constructor for use with Pdco model (note modified for pdco!!!!) */
-  ClpLsqr(ClpInterior *model);
-  /// Copy constructor 
-  ClpLsqr(const ClpLsqr &);
-  /// Assignment operator. This copies the data
-    ClpLsqr & operator=(const ClpLsqr & rhs);
-  /** Destructor */
-  ~ClpLsqr();
-  //@}
+     /** Constructor for use with Pdco model (note modified for pdco!!!!) */
+     ClpLsqr(ClpInterior *model);
+     /// Copy constructor
+     ClpLsqr(const ClpLsqr &);
+     /// Assignment operator. This copies the data
+     ClpLsqr & operator=(const ClpLsqr & rhs);
+     /** Destructor */
+     ~ClpLsqr();
+     //@}
 
-  /**@name Methods */
-  //@{
-  /// Set an int parameter
-  bool setParam(char *parmName, int parmValue);
-  /// Call the Lsqr algorithm
- void do_lsqr( CoinDenseVector<double> &b,  
-		double damp, double atol, double btol, double conlim, int itnlim, 
-		bool show, Info info, CoinDenseVector<double> &x , int *istop,
-		int *itn, Outfo *outfo, bool precon, CoinDenseVector<double> &Pr );
-  /// Matrix-vector multiply - implemented by user
-  void matVecMult( int, CoinDenseVector<double> *, CoinDenseVector<double> *);
+     /**@name Methods */
+     //@{
+     /// Set an int parameter
+     bool setParam(char *parmName, int parmValue);
+     /// Call the Lsqr algorithm
+     void do_lsqr( CoinDenseVector<double> &b,
+                   double damp, double atol, double btol, double conlim, int itnlim,
+                   bool show, Info info, CoinDenseVector<double> &x , int *istop,
+                   int *itn, Outfo *outfo, bool precon, CoinDenseVector<double> &Pr );
+     /// Matrix-vector multiply - implemented by user
+     void matVecMult( int, CoinDenseVector<double> *, CoinDenseVector<double> *);
 
-  void matVecMult( int, CoinDenseVector<double> &, CoinDenseVector<double> &);
-  /// diag1 - we just borrow as it is part of a CoinDenseVector<double>
-  void borrowDiag1(double * array)
-  { diag1_=array;};
-  //@}
+     void matVecMult( int, CoinDenseVector<double> &, CoinDenseVector<double> &);
+     /// diag1 - we just borrow as it is part of a CoinDenseVector<double>
+     void borrowDiag1(double * array) {
+          diag1_ = array;
+     };
+     //@}
 };
 #endif
 
 
 
-    
+
